aboutsummaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/libhomescreen.cpp49
1 files changed, 38 insertions, 11 deletions
diff --git a/src/libhomescreen.cpp b/src/libhomescreen.cpp
index ad18ca4..dd5d363 100644
--- a/src/libhomescreen.cpp
+++ b/src/libhomescreen.cpp
@@ -123,8 +123,9 @@ LibHomeScreen::~LibHomeScreen()
* This function is initializer
*
* #### Parameters
* - port [in] : This argument should be specified to the port number to be used for websocket
* - token [in] : This argument should be specified to the token to be used for websocket
*
* #### Return
* Nothing
@@ -133,20 +134,16 @@ LibHomeScreen::~LibHomeScreen()
* Use this constructor
*
*/
-int LibHomeScreen::init(const int port, const string& token)
+int LibHomeScreen::init(const char *hostname, const int port, const char *token)
{
int ret = 0;
- if(port > 0 && token.size() > 0)
- {
- mport = port;
- mtoken = token;
- }
- else
+ if(port < 0 || token == nullptr || token[0] == 0)
{
HMI_ERROR("libhomescreen","port and token should be > 0, Initial port and token uses.");
}
- ret = initialize_websocket();
+ ret = initialize_websocket(hostname, port, token);
+
if(ret != 0 )
{
HMI_ERROR("libhomescreen","Failed to initialize websocket");
@@ -159,6 +156,25 @@ int LibHomeScreen::init(const int port, const string& token)
}
/**
+ * This function is initializer
+ *
+ * #### Parameters
+ * - port [in] : This argument should be specified to the port number to be used for websocket
+ * - token [in] : This argument should be specified to the token to be used for websocket
+ *
+ * #### Return
+ * Nothing
+ *
+ * #### Note
+ * Use this constructor
+ *
+ */
+int LibHomeScreen::init(const int port, const string& token)
+{
+ return init(nullptr, port, token.c_str());
+}
+
+/**
* This function register callback function for reply/event message from home screen
*
* #### Parameters
@@ -187,6 +203,7 @@ int LibHomeScreen::initialize_websocket()
mploop = NULL;
onEvent = nullptr;
onReply = nullptr;
+
int ret = sd_event_new(&mploop);
if(ret < 0)
{
@@ -204,7 +221,7 @@ int LibHomeScreen::initialize_websocket()
minterface.on_hangup = _on_hangup_static;
minterface.on_call = _on_call_static;
minterface.on_event = _on_event_static;
- muri += "ws://localhost:" + to_string(mport) + "/api?token=" + mtoken; /*To be modified*/
+
sp_websock = afb_ws_client_connect_wsj1(mploop, muri.c_str(), &minterface, this);
if(sp_websock == NULL)
{
@@ -220,6 +237,16 @@ END:
return -1;
}
+int LibHomeScreen::initialize_websocket(const char *hostname, const int port, const char *token)
+{
+ if (hostname == nullptr)
+ hostname = "localhost";
+ muri = std::string("ws://") + hostname + ":" + to_string(port) + "/api?token=" + token; /*To be modified*/
+
+ return initialize_websocket();
+}
+
+
/**
* Sending ShortCut Icon tapped event
*
@@ -123,8 +123,9 @@ LibHomeScreen::~LibHomeScreen()
*
* #### Parameters
- * - port [in] : This argument should be specified to the port number to be used for websocket
- * - token [in] : This argument should be specified to the token to be used for websocket
+ * - hostname [in] : This argument should be specified to the hostname to be used for websocket
+ * - port [in] : This argument should be specified to the port number to be used for websocket
+ * - token [in] : This argument should be specified to the token to be used for websocket
*
* #### Return